@@ -2,18 +2,16 @@
 #######################################################################
 """Adapter owner to nickname in browse represetative
 
-$Id: owner2nicknameadapter.py 51965 2008-10-23 21:55:22Z cray $
+$Id: owner2nicknameadapter.py 52560 2009-02-11 20:08:02Z cray $
 """
 __author__  = "Andrey Orlov"
 __license__ = "GPL"
-__version__ = "$Revision: 51965 $"
+__version__ = "$Revision: 52560 $"
 
-from ng.skin.base.page.contentlet.viewletbase import ViewletBase
-from ng.content.comment.interfaces import ICommentAnnotation
 from zope.app.zapi import getUtility
 from zope.app.catalog.interfaces import ICatalog
 from ng.adapter.adaptiveurl.adaptiveurl import adaptiveURL
-from ng.content.annotation.profileannotation.interfaces import IProfileAnnotation
+from ng.content.profile.profileannotation.interfaces import IProfileAnnotation
 
 class Owner2NicknameAdapter(object) :
     """ Owner 2 nickname adapter """
@@ -23,12 +21,13 @@ class Owner2NicknameAdapter(object) :
         self.request = request
         
     def __getitem__(self,author) :
-      print 'qq', author
+      if author is None :
+         return u""
+         
       for profile in getUtility(ICatalog,context=self.context) \
                           .searchResults(
                               profile=( unicode(author), unicode(author) )
                           ) :
-          print "Profile", profile, author, type(author), self.context
           return """<a class="nickname" href="%(href)s"> %(author)s</a>""" % {
                     "author" : IProfileAnnotation(profile).nickname,
                     "href" : adaptiveURL(profile,self.request)
