@@ -3,12 +3,12 @@
 
 """Search adapter for the Zope 3 neural content site
 
-$Id: searchadapter.py 51189 2008-06-26 11:21:11Z cray $
+$Id: searchadapter.py 53379 2009-07-05 20:49:33Z cray $
 """
 __author__  = "Andrey Orlov, 2007-02-20"
 __license__ = "GPL"
-__version__ = "$Revision: 51189 $"
-__date__ = "$Date: 2008-06-26 15:21:11 +0400 (Чтв, 26 Июн 2008) $"
+__version__ = "$Revision: 53379 $"
+__date__ = "$Date: 2009-07-06 00:49:33 +0400 (Пнд, 06 Июл 2009) $"
  
 from zope.interface import Interface 
 
@@ -21,6 +21,10 @@ from ng.adapter.mtime.interfaces import IMTime
 from ng.adapter.path.interfaces import IPath
 from pd.refchecker.refchecker import SearchReferenceAdapter
 from ng.content.annotation.dictannotation.interfaces import IDictAnnotation
+from ng.content.article.interfaces import IDocShort
+
+import re
+rspace = re.compile("\s+",re.U)
 
 def catch(f) :
     def c(self,*kv,**kw) :
@@ -41,8 +45,13 @@ class SearchAdapter(object) :
     @property
     @catch
     def name(self) :
-        return IPath(self.ob).tailpath
-
+        try :
+            title = (IDocShort(self.ob).title.lower(),)
+        except TypeError,msg :
+            print msg
+            title = ()            
+        return [ re.sub(rspace," ",x).strip() for x in  IPath(self.ob).tailpath + title ]
+        
     @property
     @catch
     def names(self) :
@@ -60,7 +69,7 @@ class SearchAdapter(object) :
     @Lazy
     def keyword(self) :
         try :
-            return [x.strip().lower() for x in IDictAnnotation(self.ob).keyword]
+            return [re.sub(rspace," ",x.strip()).lower() for x in IDictAnnotation(self.ob).keyword]
         except TypeError :
             return []            
 
